@@ -17,6 +17,7 @@ from xml.parsers.expat import ExpatError
 from django.http import HttpResponse, Http404
 from django.shortcuts import render_to_response
 from django.conf import settings
+from django.core.urlresolvers import reverse, NoReverseMatch
 from rpcdispatcher import RPCDispatcher
 
 # these restrictions can change the functionality of rpc4django
@@ -35,10 +36,6 @@ restrict_rpctest = getattr(settings, 'RPC4DJANGO_RESTRICT_RPCTEST', False)
 # get a list of the installed django applications
 # these will be scanned for @rpcmethod decorators
 apps = getattr(settings, 'INSTALLED_APPS', [])
-
-# instantiate the rpcdispatcher -- this examines the INSTALLED_APPS
-# for any @rpcmethod decorators and adds them to the callable methods
-dispatcher = RPCDispatcher(apps, restrict_introspection) 
     
 
 def serve_rpc_request(request):
@@ -110,8 +107,19 @@ def serve_rpc_request(request):
         methods = dispatcher.list_methods()
         c = {
             'methods': methods,
+            'url': URL,
             
             # restricts the ability to test the rpc server from the docs
             'restrict_rpctest': restrict_rpctest,
         }
         return render_to_response('rpc4django/rpcmethod_summary.html', c)
+
+# reverse the method for use with system.describe and ajax
+try:
+    URL = reverse(serve_rpc_request)
+except NoReverseMatch:
+    URL = ''
+    
+# instantiate the rpcdispatcher -- this examines the INSTALLED_APPS
+# for any @rpcmethod decorators and adds them to the callable methods
+dispatcher = RPCDispatcher(URL, apps, restrict_introspection) 
